<?php
	/**
	* A class for reading Microsoft Excel Spreadsheets.
	* Originally developed by Vadim Tkachenko under the name PHPExcelReader.
	* (http://sourceforge.net/projects/phpexcelreader)
	* Based on the Java version by Andy Khan (http://www.andykhan.com).  Now
	* maintained by David Sanders.  Reads only Biff 7 and Biff 8 formats.
	*
	* PHP versions 4 and 5
	*
	* @author Vadim Tkachenko <vt@apachephp.com>
	* @author Sigurd Nes <sigurdne@online.no>
	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
	* @package phpgwapi
	* @subpackage utilities
 	* @version $Id: class.excelreader.inc.php 682 2008-02-01 12:19:55Z dave $
	*
	*/

	
	/**
	* 
	*/
	require_once(PHPGW_API_INC . '/excelreader/reader.php');

?>
